CodeDisplayService class

Mixed-in types
  • VMServiceWrapper

Constructors

CodeDisplayService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceWrapper → ServiceWrapper
finalinherited

Methods

getIdWithClassName(String className) → Future<String?>
getScriptIdsWithKeyword(String keyword) → Future<Map<String?, String?>>
getScriptIdWithFileName(String fileName) → Future<String?>
getSourceCodeWithScriptId(String scriptId) → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited