PageInfoHelper class

Constructors

PageInfoHelper()

Properties

element → Element?
no setter
filePath → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
line → int?
no setter
message → String
no setter
renderObject → RenderObject?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection → InspectorSelection
final

Methods

getCode() → Future<String?>
getCodeByFileName(String fileName) → Future<String?>
getCodeListByKeyword(String keyword) → Future<Map<String?, String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packagePathConvertFromFilePath(String filePath) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited