SyntaxHighlighterStyle class

Constructors

SyntaxHighlighterStyle({TextStyle? baseStyle, TextStyle? numberStyle, TextStyle? commentStyle, TextStyle? keywordStyle, TextStyle? stringStyle, TextStyle? punctuationStyle, TextStyle? classStyle, TextStyle? constantStyle})

Properties

baseStyle → TextStyle?
final
classStyle → TextStyle?
final
commentStyle → TextStyle?
final
constantStyle → TextStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
keywordStyle → TextStyle?
final
numberStyle → TextStyle?
final
punctuationStyle → TextStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringStyle → TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited